summaryrefslogtreecommitdiff
path: root/xmlComments.go
diff options
context:
space:
mode:
Diffstat (limited to 'xmlComments.go')
-rw-r--r--xmlComments.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/xmlComments.go b/xmlComments.go
index b4602fc..731f416 100644
--- a/xmlComments.go
+++ b/xmlComments.go
@@ -72,8 +72,8 @@ type xlsxPhoneticRun struct {
T string `xml:"t"`
}
-// formatComment directly maps the format settings of the comment.
-type formatComment struct {
+// commentOptions directly maps the format settings of the comment.
+type commentOptions struct {
Author string `json:"author"`
Text string `json:"text"`
}